@@ -17,7 +17,7 @@ use JSON qw/decode_json/;
 use WWW::Mechanize;
 use Path::Tiny;
 
-our $VERSION = version->new('0.6.7');
+our $VERSION = version->new('0.6.8');
 
 extends 'Group::Git';
 
@@ -60,10 +60,13 @@ sub _repos {
             my $project = $repo->{project}{name};
             my $url     = $repo->{links}{self}[0]{href};
             my %clone   = map {($_->{name} => $_->{href})} @{ $repo->{links}{clone} };
-            my $dir     = $self->recurse ? path("$project/$repo->{name}") : path($repo->{name});
+            my $git     = $conf->{clone_type} && $conf->{clone_type} eq 'http' ? $clone{http} : $clone{ssh};
+            my ($dir)   = $self->recurse ? $git =~ m{([^/]+/[^/]+?)(?:[.]git)?$} : $git =~ m{/([^/]+?)(?:[.]git)?$};
+            my $name    = $self->recurse ? path("$project/$repo->{name}") : path($repo->{name});
+            $dir =~ s/^~//xms;
 
             $repos{$dir} = Group::Git::Repo->new(
-                name => $dir,
+                name => path($dir),
                 url  => $url,
                 git  => $conf->{clone_type} && $conf->{clone_type} eq 'http' ? $clone{http} : $clone{ssh},
             );
@@ -73,6 +76,9 @@ sub _repos {
             if ( $repo->{project}{owner} ) {
                 push @{ $conf->{tags}{personal} }, "$dir";
             }
+            else {
+                push @{ $conf->{tags}{project} }, "$dir";
+            }
         }
         $more  = !$response->{isLastPage};
         $start = $response->{nextPageStart};
@@ -91,7 +97,7 @@ Group::Git::Stash - Adds reading all repositories you have access to on your loc
 
 =head1 VERSION
 
-This documentation refers to Group::Git::Stash version 0.6.7.
+This documentation refers to Group::Git::Stash version 0.6.8.
 
 =head1 SYNOPSIS
 
